HealthSyncClient class abstract
Vendor-neutral health quantity sync (HealthKit / Health Connect).
Defaults to NoopHealthSyncClient. Production shells override via
kozmonos_adapter_health_platform / KozmonosHealthKit.platform().
- Implementers
Constructors
Properties
- backend → HealthSyncBackend
-
no setter
-
hasAuthorization
→ Future<
bool> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
isTypeAvailable
→ Future<
bool> -
Whether the configured sample type (e.g. alcohol) exists on this device.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteDay(
DateTime date) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
readRange(
{required DateTime from, required DateTime to}) → Future< List< HealthDayQuantity> > -
requestAuthorization(
) → Future< bool> -
toString(
) → String -
A string representation of this object.
inherited
-
writeDayCount(
{required DateTime date, required double count}) → Future< void> -
Write
countfordate. Passcount <= 0to delete that day.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited